@@ -52,6 +52,9 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
             else:
                 outcoords = coords
         cocosel = cosel(coords = coords, outcoords = outcoords)
+    else:
+        if (outcoords == None):
+            outcoords = cocosel
 
     # remove NA (None) values if specified
     # would be more elegant if we could simply do cosel = cosel[cosel!=None], but None inside [] does strange things
@@ -63,9 +66,9 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
                 tempcosel.append(ecosel)
                 tempoutcoords.append(outcoords[icosel])
         cocosel = array(tempcosel)
-        outcoords = array(outcoords)
+        outcoords = array(tempoutcoords)
 
-    dataout = tile(None,len(cocosel))
+    dataout = tile(nan,len(cocosel))
     #dataout = indata[cosel[cosel!=None]]
     #dataout[cosel==None] = nan
     #dataout[cosel!=None] = indata[cosel[cosel!=None]]
@@ -74,7 +77,7 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
             dataout[iel] = indata[el]
         else:
             dataout[iel] = None
-    return list([dataout, outcoords])
+    return(list([array(dataout), array(outcoords)]))
 
 
 # aim: build an array (boolean) selection from indices of any dimension
